<p align="center">
    <a href="https://project-sthali.github.io/sthali-backend/images/sthali-backend.svg">
        <img src="https://project-sthali.github.io/sthali-backend/images/sthali-backend.svg" alt="sthali-backend">
    </a>
    <em>A FastAPI package for implement services</em>
</p>
<p align="center">
    <a href="https://github.com/project-sthali/sthali-backend/actions/workflows/tests.yml" target="_blank">
        <img src="https://github.com/project-sthali/sthali-backend/actions/workflows/tests.yml/badge.svg" alt="">
    </a>
    <a href="https://github.com/project-sthali/sthali-backend/actions/workflows/deploy.yml" target="_blank">
        <img src="https://github.com/project-sthali/sthali-backend/actions/workflows/deploy.yml/badge.svg" alt="">
    </a>
    <a href="https://github.com/project-sthali/sthali-backend/actions/workflows/docs.yml" target="_blank">
        <img src="https://github.com/project-sthali/sthali-backend/actions/workflows/docs.yml/badge.svg?branch=development" alt="">
    </a>
</p>

<p align="center">
    <a href="https://project-sthali.github.io/sthali-backend/license/" target="_blank">
        <img alt="License" src="https://img.shields.io/github/license/project-sthali/sthali-backend">
    </a>
    <a href="https://github.com/project-sthali/sthali-backend/releases" target="_blank">
        <img alt="Release" src="https://img.shields.io/github/v/release/project-sthali/sthali-backend">
    </a>
</p>

**Docs**: [https://project-sthali.github.io/sthali-backend/](https://project-sthali.github.io/sthali-backend/)

**PyPI**: [https://pypi.org/project/sthali-backend/](https://pypi.org/project/sthali-backend/)

**Source**: [https://github.com/project-sthali/sthali-backend/](https://github.com/project-sthali/sthali-backend/)

**Board**: [https://github.com/users/project-sthali/projects/1/](https://github.com/users/project-sthali/projects/1/)

---

### Requirements

#### Prerequisites
- `python >= 3.10`
- `pip` package manager

#### Runtime Dependencies
This project requires the following Python packages with specific versions:

- `sthali-crud >= 0.0.7`



#### Optional Dependencies
This project has optional dependencies that can be installed for additional features:

##### dev

- `coverage[toml] >= 7.9.1`

- `ruff >= 0.12.0`


##### tests

- `coverage[toml] >= 7.9.1`


##### stage

- `build >= 1.2.1`

- `coverage[toml] >= 7.9.1`




---

### Instalation

#### Using PYPI

```
pip install sthali-backend
```

#### Using GitHub repo

```
git clone https://github.com/project-sthali/sthali-backend.git
cd sthali-backend
pip install .
```

---

### Usage

nothing to see here, plz disperse
